# User Documentation

Documentation for end users of MCP Ticketer.

## Getting Started

New to MCP Ticketer? Start here:

1. **[Quick Start Guide](getting-started/QUICK_START.md)** - Get up and running in 5 minutes
2. **[Quick Environment Setup](getting-started/QUICK_START_ENV.md)** - Fast environment configuration
3. **[Configuration Guide](getting-started/CONFIGURATION.md)** - Complete configuration reference

## Guides

- **[User Guide](guides/USER_GUIDE.md)** - Complete user documentation
- **[Bulletproof Ticket Creation](guides/BULLETPROOF_TICKET_CREATION.md)** - Best practices for ticket creation
- **[Epic Attachments Guide](guides/EPIC_ATTACHMENTS.md)** - Working with epic attachments

## Features

- **[Feature Overview](features/README.md)** - All features at a glance
- **[Ticket Instructions](features/ticket_instructions.md)** - Customizing ticket writing instructions
- **[Automatic Validation](features/AUTOMATIC_VALIDATION.md)** - Automatic ticket validation
- **[Update Checking](features/UPDATE_CHECKING.md)** - Version update checking

## See Also

- [Integration Guides](../integrations/README.md) - Platform-specific setup guides
- [Developer Documentation](../developer-docs/README.md) - For contributors
- [Architecture Documentation](../architecture/README.md) - Technical deep-dives
